==> haskell-shakespeare-2.0.14-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-shakespeare.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: shakespeare
version: 2.0.14
id: shakespeare-2.0.14-2RhgkLt2BZ2FcVRcUHxGbk
key: shakespeare-2.0.14-2RhgkLt2BZ2FcVRcUHxGbk
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/shakespearean-templates
synopsis: A toolkit for making compile-time interpolated templates
description:
    Shakespeare is a family of type-safe, efficient template languages. Shakespeare templates are expanded at compile-time, ensuring that all interpolated variables are in scope. Variables are interpolated according to their type through a typeclass.
    .
    Shakespeare templates can be used inline with a quasi-quoter or in an external file.
    .
    Note there is no dependency on haskell-src-extras. Instead Shakespeare believes logic should stay out of templates and has its own minimal Haskell parser.
    .
    Packages that use this: xml-hamlet
    .
    Please see the documentation at <http://www.yesodweb.com/book/shakespearean-templates> for more details.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Text.Cassius Text.Coffee Text.Hamlet Text.Hamlet.RT
    Text.Hamlet.Runtime Text.Internal.Css Text.Internal.CssCommon
    Text.Julius Text.Lucius Text.Roy Text.Shakespeare
    Text.Shakespeare.Base Text.Shakespeare.I18N Text.Shakespeare.Text
    Text.TypeScript
hidden-modules: Text.Hamlet.Parse Text.MkSizeType
                Text.IndentToBrace
abi: c1be0c7e3aef06708629b91f4c947edf
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/shakespeare-2.0.14
library-dirs: /usr/lib/ghc-8.2.1/site-local/shakespeare-2.0.14
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/shakespeare-2.0.14
hs-libraries: HSshakespeare-2.0.14-2RhgkLt2BZ2FcVRcUHxGbk
depends:
    base-4.10.0.0 time-1.8.0.2 containers-0.5.10.2
    template-haskell-2.12.0.0 parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz process-1.6.1.0
    ghc-prim-0.5.1.0 bytestring-0.10.8.2 directory-1.3.0.2
    aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y
    blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL
    blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh
    exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6 transformers-0.5.2.0
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
             parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh=da03630454c215de5f3965e7b0f0e5da
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
             ghc-prim-0.5.1.0=557c7fce76ef13c2417583cc28848f14
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=1bd098f0c2fb1217cc4d33a7e7a9941a
             blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL=f07231ccbdf42fb50e1dae1144230e4a
             blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh=a026cdf45341163ef88f9856837f267f
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=e190029673d5410544b32623a0e81f5f
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q=a0445f54fa186d288e1223c9f60f5307
haddock-interfaces: /usr/share/doc/haskell-shakespeare/html/shakespeare.haddock
haddock-html: /usr/share/doc/haskell-shakespeare/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shakespeare-2.0.14-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-shakespeare.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: shakespeare
version: 2.0.14
id: shakespeare-2.0.14-ILbjPbZM5dUCAePhfgNGCi
key: shakespeare-2.0.14-ILbjPbZM5dUCAePhfgNGCi
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/shakespearean-templates
synopsis: A toolkit for making compile-time interpolated templates
description:
    Shakespeare is a family of type-safe, efficient template languages. Shakespeare templates are expanded at compile-time, ensuring that all interpolated variables are in scope. Variables are interpolated according to their type through a typeclass.
    .
    Shakespeare templates can be used inline with a quasi-quoter or in an external file.
    .
    Note there is no dependency on haskell-src-extras. Instead Shakespeare believes logic should stay out of templates and has its own minimal Haskell parser.
    .
    Packages that use this: xml-hamlet
    .
    Please see the documentation at <http://www.yesodweb.com/book/shakespearean-templates> for more details.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Text.Cassius Text.Coffee Text.Hamlet Text.Hamlet.RT
    Text.Hamlet.Runtime Text.Internal.Css Text.Internal.CssCommon
    Text.Julius Text.Lucius Text.Roy Text.Shakespeare
    Text.Shakespeare.Base Text.Shakespeare.I18N Text.Shakespeare.Text
    Text.TypeScript
hidden-modules: Text.Hamlet.Parse Text.MkSizeType
                Text.IndentToBrace
abi: 5b0146feaa47ba68d8065943ed5853bc
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/shakespeare-2.0.14
library-dirs: /usr/lib/ghc-8.2.1/site-local/shakespeare-2.0.14
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/shakespeare-2.0.14
hs-libraries: HSshakespeare-2.0.14-ILbjPbZM5dUCAePhfgNGCi
depends:
    base-4.10.0.0 time-1.8.0.2 containers-0.5.10.2
    template-haskell-2.12.0.0 parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz process-1.6.1.0
    ghc-prim-0.5.1.0 bytestring-0.10.8.2 directory-1.3.0.2
    aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq
    blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL
    blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh
    exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6 transformers-0.5.2.0
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
             parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh=da03630454c215de5f3965e7b0f0e5da
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
             ghc-prim-0.5.1.0=557c7fce76ef13c2417583cc28848f14
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq=8b90ef7c46d906c8047345fb433e32fe
             blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL=f07231ccbdf42fb50e1dae1144230e4a
             blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh=a026cdf45341163ef88f9856837f267f
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=e190029673d5410544b32623a0e81f5f
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q=a0445f54fa186d288e1223c9f60f5307
haddock-interfaces: /usr/share/doc/haskell-shakespeare/html/shakespeare.haddock
haddock-html: /usr/share/doc/haskell-shakespeare/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
